#!/usr/bin/env python3

# Macaw
#
# Testing file open and string concatenation.

import random

def main():

    # This dictionary of words is for testing only and should *not* be considered secure.
    # Courtesy of https://gist.github.com/deekayen/4148741
    f = open('dictionary.txt')
    wordList = f.read().split()

    password = generatePassword(wordList)
    speakPassword(password)

def speakPassword(str):
    print(r"""
                   ,,,___
                 ,'   _  \__           ___________________________________________
                /    { O /  `\        /                                           \
               ,\     } /---./     .-'      """+str+"""
             /\  `-.__- `--'       `-.                                             |
            /  `._  :   |             \___________________________________________/
           /\_;  -' :   ;
           /  \_;  /   /
           /| \ \_/..-'
   ________|_\___/_\\\_\\\________
   ----------------;;-;;--------
           \/ `-'/
           |\_|_/|
            \/ \/
             \_/
    """)

def generatePassword(wordList):
    tempPass = ''
    for i in range(0, 5):
        word = wordList[random.randint(0,999)] # grab a random word from the dictionary file.
        tempPass = tempPass + word #concat that word to the end of the password.
    return tempPass



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="macawspeak",
#    packages=["macaw"],
    version="0.1.1",
    author="Dakota Chambers",
    author_email="dakotachambers@gmail.com",
    description="Better password generation inspired by our colorful, feathered friends.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/dcchambers/macaw",
    include_package_data=True,
    packages=setuptools.find_packages(),
    keywords = [
		"password",
        "macaw",
	],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points = {
		"console_scripts": [
			"macaw=macaw.macaw:main"
		]
	}
)
